@@ -1,14 +1,17 @@
 import os
+
 import pytest
 from dotenv import load_dotenv
 
 from sqlitecloud.client import SqliteCloudClient
 from sqlitecloud.types import SQCloudConnect, SqliteCloudAccount
 
+
 @pytest.fixture(autouse=True)
 def load_env_vars():
     load_dotenv(".env")
 
+
 @pytest.fixture()
 def sqlitecloud_connection():
     account = SqliteCloudAccount()
@@ -16,7 +19,7 @@ def sqlitecloud_connection():
     account.password = os.getenv("SQLITE_PASSWORD")
     account.dbname = os.getenv("SQLITE_DB")
     account.hostname = os.getenv("SQLITE_HOST")
-    account.port = 8860
+    account.port = int(os.getenv("SQLITE_PORT"))
 
     client = SqliteCloudClient(cloud_account=account)
 
@@ -26,4 +29,4 @@ def sqlitecloud_connection():
 
     yield (connection, client)
 
-    client.disconnect(connection)
\ No newline at end of file
+    client.disconnect(connection)
