@@ -1,12 +1,10 @@
-import os
 import sqlite3
 import tempfile
 
 import pytest
 
 from sqlitecloud import download
-from sqlitecloud.client import SqliteCloudClient
-from sqlitecloud.types import SQCLOUD_ERRCODE, SQCloudConnect, SQCloudException, SqliteCloudAccount
+from sqlitecloud.types import SQCLOUD_ERRCODE, SQCloudException
 
 
 class TestDownload:
@@ -31,4 +29,4 @@ class TestDownload:
             download.download_db(connection, "missing.sqlite", temp_file)
 
         assert e.value.errcode == SQCLOUD_ERRCODE.COMMAND.value
-        assert e.value.errmsg == "Database missing.sqlite does not exist."
\ No newline at end of file
+        assert e.value.errmsg == "Database missing.sqlite does not exist."
